@@ -19,6 +19,8 @@ for c in levels(cs)
     for l in lines(c)
         x, y = coordinates(l)
         @assert typeof(x) == typeof(y) == Vector{Float64}
+        xy = vertices(l)
+        @test xy isa Vector{Tuple{Float64,Float64}}
     end
 end
 
